/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Aditya Chakraborty <info@bhartiy.com> - http://www.bhartiy.com
 */

var JFormFieldAutocomplete = function () {
    this.options = {
        id: 'jform',
        name: 'jform'
    };
};

(function ($) {
    JFormFieldAutocomplete.prototype = {
        setup: function (options) {
            $.extend(this.options, options);
            this.select2();
            return this;
        },

        select2: function () {
            var $this = this;
            var $id = '#' + this.options.id;

            $($id).select2({
                allowClear: true,
                multiple: $this.options.multiple,
                minimumInputLength: 0,
                placeholder: $this.options.hint || ' ',
                ajax: {
                    url: $this.options.ajax_url,
                    dataType: 'json',
                    data: function (term, page) {
                        return {
                            query: term,
                            list_start: $this.options.limit * (page - 1),
                            list_limit: $this.options.limit,
                            default_options: $this.options.default_options,
                        };
                    },
                    results: function (response, page) {
                        // Parse the results into the format expected by Select2.
                        // If we are using custom formatting functions we do not need to alter remote JSON data
                        var results = [];

                        if (response.success) {
                            $.each(response.data, function (i, v) {
                                results.push({
                                    id: v.id,
                                    text: (v.full_title || v.title),
                                    disabled: v.disabled,
                                    formatted_text: v.formatted_title
                                });
                            });
                        }

                        return {results: results};
                    }
                },
                initSelection: function (element, callback) {
                    // The input tag has a value attribute preloaded that points to a preselected items id
                    // This function resolves that id attribute to an object that select2 can render
                    // using its formatResult renderer - that way the item title is shown preselected
                    var values = $(element).val();

                    if (values === '') return;

                    $.ajax({
                        url: $this.options.info_url,
                        dataType: 'json',
                        data: {
                            id: values.split(','),
                            default_options: $this.options.default_options,
                        },
                    }).done(function (response) {
                        var results = [];
                        var new_values = [];

                        if (response.success) {
                            $.each(response.data, function (i, v) {
                                new_values.push(v.id);
                                results.push({
                                    id: v.id,
                                    text: (v.full_title || v.title),
                                    formatted_text: v.formatted_title
                                });
                            });
                        }
                        $(element).val(new_values.join(','));
                        // {id, text} for single-select, [{id, text},{id, text}] for multi-select
                        callback($this.options.multiple ? results : results[0]);
                    }).fail(function (response) {
                        console.log(response.responseText);
                    });
                },
                formatResult: function (result) {
                    return result.text;
                },
                formatSelection: function (result) {
                    return result.formatted_text || result.text;
                }
            });
        }
    }

    $(document).ready(function () {
        $('.field-autocomplete').each(function () {
            var o = new JFormFieldAutocomplete;

            let $this = $(this);
            o.setup({
                ajax_url : $this.data('ajax-url'),
                info_url : $this.data('info-url'),
                id : $this.attr('id'),
                name : $this.attr('name'),
                multiple : $this.data('multiple'),
                hint : $this.data('hint'),
                limit : $this.data('limit'),
                default_options : $this.data('default-options'),
            });
        });
    });
})(jQuery);
