/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Aditya Chakraborty <info@bhartiy.com> - http://www.bhartiy.com
 */
jQuery(document).ready(function ($) {
    var addToCart = function (btn, empty_cart) {
        if (typeof empty_cart === "undefined") {
            empty_cart = false;
        }

        var $cartModal = $('#modal-cart');

        var code = btn.data('item');
        var checkout = btn.data('checkout');
        if (!code) return;
        var q = $('#product-quantity').length ? ($('#product-quantity').val() || 1) : 1;
        var paths = Joomla.getOptions('system.paths', {});
        var base = paths.base || paths.root || '';

        var data = {p: code, quantity: q};
        data.options = {};

        $(document).trigger('onAddCartOptions', [data.options, btn]);

        if (empty_cart) {
            data.options.empty_cart = 1;
        }

        if ($('.checkout_form').length) {
            let form = $('.checkout_form');

            if (!document.formvalidator.isValid(form)) {
                return;
            }

            let formData = form.serializeArray();

            formData.forEach(function(field, key){
                data[field.name] = field.value;
            });
        }

        $.ajax({
            url: base + '/index.php?option=com_sellacious&task=cart.addAjax&format=json',
            type: 'POST',
            data: data,
            cache: false,
            dataType: 'json'
        }).done(function (response) {
            if (response.state == 1) {
                $(document).trigger('cartUpdate', ['add', {uid: response.data.uid}]);

                if (window.parent !== window.top) {
                    // There's no way to trigger parent window's event so we will send a message to parent as an alternative
                    window.parent.postMessage(JSON.stringify({
                        triggerEvent: "cartUpdate",
                        method: "add",
                        args: {uid: response.data.uid}
                    }), '*');
                }

                Joomla.renderMessages({success: [response.message]});
                if (checkout && response.data['redirect']) {
                    window.location.href = response.data['redirect'];
                } else if ($cartModal.length) {
                    // Close any active modals first
                    $('.ctech-modal').ctechmodal('hide');

                    // Open cart in modal
                    var o = $cartModal.data('CartModal');
                    o.navStep('cart');
                    $cartModal.ctechmodal('show');
                }
            } else if(response.state == 1000) {
                if (confirm(response.message)) {
                    addToCart(btn, true);
                } else {
                    return false;
                }
            } else {
                Joomla.renderMessages({error: [response.message]});
            }
        }).fail(function (jqXHR) {
            Joomla.renderMessages({error: ['There was an error while processing your request. Please try later.']});
            console.log(jqXHR.responseText);
        });
    };

    $('.btn-add-cart').click(function (){
        addToCart($(this));
    });
});
