<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Aditya Chakraborty <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access
use Joomla\Registry\Registry;
use Joomla\Utilities\ArrayHelper;
use Sellacious\Price\PriceHelper;

defined('_JEXEC') or die;

/** @var SellaciousViewProduct $this */
/** @var  array  $tplData */
$item        = $this->item;
$listingType = (int) ArrayHelper::getValue($tplData, 'listing_type', 1);
$condition   = ArrayHelper::getValue(array('', 'NEW', 'USED', 'REFURBISHED'), $listingType, '');
$lists       = (array) $item->get('listings_by_type.' . $listingType . '.items');
?>
<div class="lists-infobox variants-list">
	<div class="ctech-container-fluid">
		<div class="ctech-row">
			<?php foreach ($lists as $i => $list):
				/** @var Registry $item */
				$item       = new Registry($list);
				$s_currency = $this->helper->currency->forSeller($item->get('seller.seller_uid'), 'code_3');
				$images     = $item->get('images');

				$link           = JRoute::_('index.php?option=com_sellacious&view=product&p=' . $item->get('code'));
				$rating_display = (array) $this->helper->config->get('product_rating_display');
				$priceHandler   = PriceHelper::getHandler($item->get('pricing_type'));
				?>
				<div class="ctech-col-md-6 single-variant">
					<div class="variant-thumb bgrollover">
						<span style="background-image: url('<?php echo reset($images); ?>')"
						      data-rollover="<?php echo htmlspecialchars(json_encode($images)); ?>"></span>
					</div>

					<div class="variant-info">
						<div class="variant-title">
							<a href="<?php echo $link; ?>"><?php echo $item->get('product_title'); ?> <?php
								echo $item->get('variant_id') > 0 && $item->get('variant_title') ? ' - ' . $item->get('variant_title') : ''; ?></a>
						</div>
						<div class="sold-by">
							<?php echo JText::_('COM_SELLACIOUS_PRODUCT_SOLD_BY') . ' : '; ?>
							<a class="seller-title" href="<?php echo JRoute::_('index.php?option=com_sellacious&view=store&id=' . $item->get('seller_uid')); ?>">
								<?php echo $item->get('seller_store', $item->get('seller_name', $item->get('seller_company', $item->get('seller_username')))); ?>
							</a>
						</div>
						<div class="variant-price">
							<?php echo $priceHandler->renderLayout('price.minimal', $item);?>
						</div>
						<div class="variant-rating">
							<?php if ($this->helper->config->get('product_rating') && (in_array('product', $rating_display))): ?>
								<?php $rating = $item->get('product_rating.rating'); ?>
								<?php $stars = round($item->get('product_rating.rating', 0) * 2); ?>
								<div class="product-rating rating-stars">
									<span class="star-<?php echo $stars ?> fa fa-star solid-icon"></span><span class="star-<?php echo 10 - $stars ?> fa fa-star regular-icon"></span>
									<?php if ($stars > 0.0): ?>
										<span class="ctech-text-primary"><?php echo number_format($item->get('product_rating.rating', 0), 1) ?></span>
									<?php endif; ?>
									</span>
								</div><br/>
							<?php endif; ?>
						</div>

						<div class="variant-action-buttons">
							<?php
							echo $this->loadTemplate('wishlist');

							echo $priceHandler->renderLayout('checkout-buttons.small', $item);
							?>
						</div>
					</div>
					<div class="clearfix"></div>
				</div>
			<?php endforeach; ?>
		</div>
	</div>
</div>
