<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Aditya Chakraborty <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access.
defined('_JEXEC') or die;

JFormHelper::loadFieldClass('List');

/**
 * Form Field class
 *
 * @since   2.0.0
 */
class JFormFieldAutocomplete extends JFormFieldList
{
	/**
	 * The field type.
	 *
	 * @var   string
	 *
	 * @since   2.0.0
	 */
	protected $type = 'Autocomplete';

	/**
	 * @var  string
	 *
	 * @since   2.0.0
	 */
	protected $ajaxUrl = null;

	/**
	 * @var  string
	 *
	 * @since   2.0.0
	 */
	protected $infoUrl = null;

	/**
	 * Name of the layout being used to render the field
	 *
	 * @var    string
	 *
	 * @since  2.0.0
	 */
	protected $layout = 'com_sellacious.formfield.autocomplete';

	/**
	 * Method to attach a JForm object to the field.
	 *
	 * @param   SimpleXMLElement  $element  The SimpleXMLElement object representing the <field /> tag for the form field object.
	 * @param   mixed             $value    The form field value to validate.
	 * @param   string            $group    The field name group control value.
	 *
	 * @return  boolean  True on success.
	 *
	 * @since   2.0.0
	 */
	public function setup(SimpleXMLElement $element, $value, $group = null)
	{
		if (!parent::setup($element, $value, $group))
		{
			return false;
		}

		$this->ajaxUrl = (string) $this->element['ajax_url'];
		$this->infoUrl = (string) $this->element['info_url'];

		return true;
	}

	/**
	 * Method to get the field input markup.
	 *
	 * @return   string  The field input markup.
	 *
	 * @since    2.0.0
	 */
	protected function getInput()
	{
		if (empty($this->ajaxUrl) || empty($this->infoUrl))
		{
			$msg   = JText::_('COM_SELLACIOUS_FIELD_AUTOCOMPLETE_INVALID_URL');
			$input = <<<HTML
			<div class="alert alert-warning margin-top-5">
				{$msg}
			</div>
HTML;

			return $input;
		}

		JHtml::_('jquery.framework');

		if (!JFactory::getApplication()->isClient('sellacious'))
		{
			JHtml::_('ctech.select2');
		}

		JHtml::_('script', 'com_sellacious/field.autocomplete.js', false, true);

		$multiple = $this->multiple ? 'true' : 'false';
		$hint     = $this->hint ? JText::_($this->hint) : null;
		$limit    = (string) $this->element['limit'] != '' ? (int) $this->element['limit'] : 10;

		if (is_array($this->value))
		{
			$this->value = implode(',', $this->value);
		}

		$options = $this->getOptions();

		$name     = $this->name;
		$id       = $this->id;
		$class    = $this->class;
		$disabled = $this->disabled;
		$onchange = $this->onchange;
		$required = $this->required;
		$value    = htmlspecialchars($this->value, ENT_COMPAT, 'UTF-8');
		$class    = ' class=" field-autocomplete ' . $class . '"';
		$disabled = $disabled ? ' disabled' : '';
		$onchange = $onchange ? ' onchange="' . $onchange . '"' : '';
		$ajaxUrl  = $this->ajaxUrl;
		$infoUrl  = $this->infoUrl;

		$layoutOpts  = array('debug' => 0, 'client' => 0);
		$displayData = compact('name', 'id', 'class', 'disabled', 'onchange', 'required', 'value', 'class',
			'disabled', 'onchange', 'ajaxUrl', 'infoUrl', 'multiple', 'hint', 'limit', 'options');
		$input       = JLayoutHelper::render($this->layout, $displayData, JPATH_SITE . '/components/com_sellacious/layouts/', $layoutOpts);

		return $input;
	}

	/**
	 * Get input field name
	 *
	 * @param   string  $fieldName
	 *
	 * @return  string
	 *
	 * @since   2.0.0
	 */
	protected function getName($fieldName)
	{
		// Prevent names from appending [] for multiple
		$old            = $this->multiple;
		$this->multiple = false;
		$name           = parent::getName($fieldName);
		$this->multiple = $old;

		return $name;
	}
}
