<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Aditya Chakraborty <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access.
defined('_JEXEC') or die;

JFormHelper::loadFieldClass('Autocomplete');

/**
 * Form Field class
 *
 * @since   2.0.0
 */
class JFormFieldCategoryAutocomplete extends JFormFieldAutocomplete
{
	/**
	 * The field type.
	 *
	 * @var   string
	 *
	 * @since   2.0.0
	 */
	protected $type = 'CategoryAutocomplete';

	/**
	 * Method to attach a JForm object to the field.
	 *
	 * @param   SimpleXMLElement  $element  The SimpleXMLElement object representing the <field /> tag for the form field object.
	 * @param   mixed             $value    The form field value to validate.
	 * @param   string            $group    The field name group control value.
	 *
	 * @return  boolean  True on success.
	 *
	 * @since   2.0.0
	 */
	public function setup(SimpleXMLElement $element, $value, $group = null)
	{
		if (!parent::setup($element, $value, $group))
		{
			return false;
		}

		$app     = JFactory::getApplication();
		$isAdmin = $app->isClient('administrator');
		$showAll = (string) $this->element['show_all'] == 'true' ? 'true' : 'false';
		$trans   = (string) $this->element['translate'] == 'true';   // Attribute to whether translate the items or not
		$types   = (string) $this->element['group'];
		$types   = implode(',', explode(';', $types));

		$disabledSelfChild = (string) $this->element['disable_self_child'] == 'true';
		$disabledId        = $disabledSelfChild ? $this->form->getValue('id') : 0;

		$language = JFactory::getLanguage()->getTag();

		if ($trans)
		{
			$language = $this->form->getValue('language', null, $language);
		}

		if (!empty($this->ajaxUrl))
		{
			$this->ajaxUrl .= '&show_all=' . $showAll . '&language=' . $language . '&types=' . $types . '&disabled_id=' . $disabledId;

			if ($isAdmin)
			{
				$this->ajaxUrl = JUri::root() . $this->ajaxUrl;
			}
		}

		if (!empty($this->infoUrl) && $isAdmin)
		{
			$this->infoUrl = JUri::root() . $this->infoUrl;
		}

		return true;
	}
}
