<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Aditya Chakraborty <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access.
use Joomla\CMS\Layout\FileLayout;
use Sellacious\Config\ConfigHelper;

defined('_JEXEC') or die;

/**
 * Form Field class for the Joomla Framework.
 *
 * @since   2.0.0
 */
class JFormFieldTimings extends JFormField
{
	/**
	 * The field type.
	 *
	 * @var   string
	 *
	 * @since   2.0.0
	 */
	protected $type = 'Timings';

	/**
	 * The field layout.
	 *
	 * @var   string
	 *
	 * @since   2.0.0
	 */
	protected $layout = 'com_sellacious.formfield.timings';

	/**
	 * Method to get the field input markup.
	 *
	 * @return   string  The field input markup.
	 *
	 * @throws   Exception
	 *
	 * @since    2.0.0
	 */
	protected function getInput()
	{
		$this->value = is_string($this->value) ? (json_decode($this->value, true) ?: array()) : (array) $this->value;
		$this->layout = $this->element['layout'] ? $this->element['layout'] : $this->layout;

		$timeOptions = array();
		$time        = JFactory::getDate('00:00');
		$end         = clone $time;
		$end->modify("+24 hours");

		while ($time < $end) {
			$timeOptions[$time->format('h:i A')] = $time->format('h:i A');
			$time->modify('+15 minutes');
		}

		$data = array(
			'days'         => SellaciousHelperSeller::DAYS,
			'field'        => $this,
			'time_options' => $timeOptions
		);

		return JLayoutHelper::render($this->layout, $data);
	}
}
